--------------------------------------------------------------------------------
-- Company: UNIVERSITY OF CONNECTICUT
-- Engineer: John A. Chandy
--
-- Create Date:    08/22/05
-- Module Name:    debounce - Behavioral
-- Additional Comments:
--   This debounce module takes in a button press and outputs a clean signal
--   that has been debounced.  It assumes that the button will be stable after
--   2 milliseconds.  You must pass in a clock with a period of 2 ms.
--------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

---- Uncomment the following library declaration if instantiating
---- any Xilinx primitives in this code.
--library UNISIM;
--use UNISIM.VComponents.all;

entity debounce is
    Port ( button_in: in std_logic;
           button_out : out std_logic;
           twomsec_clk : in std_logic);
end debounce;

architecture Behavioral of debounce is

begin

	-- put the incoming signal through a two millisecond clock
	-- to debounce it.  Buttons on the Spartan-3 board are
	-- guaranteed to settle within 2 milliseconds.
	process( twomsec_clk )
	begin
		if ( twomsec_clk'event and twomsec_clk='1' ) then
			button_out <= button_in;
		end if;
	end process;

end Behavioral;
