--------------------------------------------------------------------------------
-- Company: UNIVERSITY OF CONNECTICUT
-- Engineer: John A. Chandy
--
-- Create Date:    08/03/05
-- Module Name:    word2leds - Behavioral
-- Additional Comments:
--   This module takes a 16 bit number and outputs it to a bank of 4 7-segment
--   LED displays.  It is assumed that the segment lines are shared between the
--   digits as with the Digilent Spartan-3 Starter Board.  The control for the
--   sharing is done with the char_led_control module
--------------------------------------------------------------------------------

library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

---- Uncomment the following library declaration if instantiating
---- any Xilinx primitives in this code.
--library UNISIM;
--use UNISIM.VComponents.all;

entity word2leds is
    Port ( word : in std_logic_vector(15 downto 0);
		seg : out std_logic_vector(6 downto 0);
		an : out std_logic_vector(3 downto 0);
		enable : in std_logic;
		onemsec_clk : in std_logic;
		sys_rst : in std_logic );
end word2leds;

architecture Behavioral of word2leds is
	signal segment0 : std_logic_vector(6 downto 0);
	signal segment1 : std_logic_vector(6 downto 0);
	signal segment2 : std_logic_vector(6 downto 0);
	signal segment3 : std_logic_vector(6 downto 0);
begin

	hex0 : entity work.hex2led
		port map ( segment => segment0,
				 hex => word(3 downto 0) );

	hex1 : entity work.hex2led
		port map ( segment => segment1,
				 hex => word(7 downto 4) );

	hex2 : entity work.hex2led
		port map ( segment => segment2,
				 hex => word(11 downto 8) );

	hex3 : entity work.hex2led
		port map ( segment => segment3,
				 hex => word(15 downto 12) );

	led_control : entity work.char_led_control
		port map ( clk => onemsec_clk,
				 reset => sys_rst,
				 enable => enable,
				 segment0 => segment0,
				 dp0 => '1',
			 	 segment1 => segment1,
				 dp1 => '1',
			 	 segment2 => segment2,
				 dp2 => '1',
			 	 segment3 => segment3,
				 dp3 => '1',
			 	 segment => seg,
			 	 an => an );

end Behavioral;
